@@ -43,6 +43,8 @@ from transonic.util import (
     is_method,
     write_if_has_to_write,
     find_module_name_from_path,
+    _get_filename_from_frame,
+    get_frame,
 )
 
 if mpi.nb_proc == 1:
@@ -54,25 +56,17 @@ modules_backends = {backend_name: {} for backend_name in backends.keys()}
 modules = modules_backends[backend_default]
 
 
-def _get_transonic_calling_module(backend_name: str = None, index_frame: int = 2):
+def _get_transonic_calling_module(backend_name: str = None):
     """Get the Transonic instance corresponding to the calling module
 
     Parameters
     ----------
 
-    index_frame : int
-
-      Index (in :code:`inspect.stack()`) of the frame to be selected
+    backend_name: str
 
     """
 
-    try:
-        frame = inspect.stack()[index_frame]
-    except IndexError:
-        print("index_frame", index_frame)
-        print([frame[1] for frame in inspect.stack()])
-        raise
-
+    frame = get_frame(2)
     module_name = get_module_name(frame)
 
     if backend_name is None:
@@ -178,7 +172,7 @@ class Transonic:
 
     frame : int (optional)
 
-      (Internal) Index (in :code:`inspect.stack()`) of the frame to be selected
+      (Internal) Frame of ``__init__`` caller.
 
     reuse : bool (optional, default True)
 
@@ -191,7 +185,7 @@ class Transonic:
     ):
 
         if frame is None:
-            frame = inspect.stack()[1]
+            frame = get_frame(1)
 
         self.module_name = module_name = get_module_name(frame)
 
@@ -237,7 +231,7 @@ class Transonic:
 
         module_backend_name += f"__{backend.name}__." + module_short_name
 
-        self.path_mod = path_mod = Path(frame.filename)
+        self.path_mod = path_mod = Path(_get_filename_from_frame(frame))
 
         suffix = ".py"
         self.path_backend = path_backend = (
@@ -329,7 +323,7 @@ class Transonic:
         else:
             self.is_compiled = backend.check_if_compiled(self.module_backend)
             if self.is_compiled:
-                module = inspect.getmodule(frame[0])
+                module = inspect.getmodule(frame)
                 # module can be None if (at least) it has been run with runpy
                 if module is not None:
                     if backend.name == "pythran":
@@ -508,11 +502,7 @@ class Transonic:
         func = getattr(self.module_backend, name)
         argument_names = self.arguments_blocks[name]
 
-        frame = inspect.currentframe()
-        try:
-            locals_caller = frame.f_back.f_locals
-        finally:
-            del frame
+        locals_caller = get_frame(1).f_locals
 
         arguments = [locals_caller[name] for name in argument_names]
         return func(*arguments)
@@ -576,7 +566,7 @@ def jit_class(cls, jit_methods, backend):
     if mpi.has_to_build(python_path, module.__file__):
         from transonic.justintime import _get_module_jit
 
-        mod = _get_module_jit(backend_name=backend.name, index_frame=5)
+        mod = _get_module_jit(backend_name=backend.name, depth_frame=5)
         if mpi.rank == 0:
             python_path = mpi.PathSeq(python_path)
             python_code = (
